@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: semigroups
 version: 0.18.1
-id: semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-key: semig_CagRMnHyiUMJkufMZJJSR4
+id: semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+key: semig_IBlkGPjZsYWGswV1yLDA9m
 license: BSD3
 copyright: Copyright (C) 2011-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -21,18 +21,18 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/semigroups-0.18.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/semigroups-0.18.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/semigroups-0.18.1
-hs-libraries: HSsemigroups-0.18.1-CagRMnHyiUMJkufMZJJSR4
+hs-libraries: HSsemigroups-0.18.1-IBlkGPjZsYWGswV1yLDA9m
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
-    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
+    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
     tagged-0.8.3-aa128de4449752177a05765fb0ce3959
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
 haddock-interfaces: /usr/share/doc/haskell-semigroups/html/semigroups.haddock
 haddock-html: /usr/share/doc/haskell-semigroups/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
